%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% RUN PROGRAM WG %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Developed in:
%%%  Department of Civil and Environmental Engineering, University of Michigan,  Ann Arbor, Michigan, USA.
%%%% Department of Civil and Environmental Engineering, Massachusetts Institute of Technology, Cambridge, Massachusetts, USA.
%%%% Dipartimento di Ingegneria Civile e Ambientale, Universit degli Studi di Firenze,  Firenze, Italy.
%%%% Institut fr Geokologie, TU Braunschweig, Langer Kamp, Braunschweig, Germany.
current_directory = cd;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Directory = uigetdir('Window','Insert Directory WG Package') ;
cd(Directory)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%HD1 = helpdlg('The HOURLY WEATHER GENERATOR is ready to be run,  ','HOURLY WEATHER GENERATOR') ;
%waitfor(HD1); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIZIALIZATION VARIABLES 
Yr = NaN;  Mo = NaN ;  Da = NaN;
Hr = NaN;  Mi =NaN;  D= NaN;
%%%---
Pr =NaN;  N=NaN;  Ta=NaN;  Rsw =NaN;  U =NaN;  Ws =NaN;  Pre =NaN;
Rdir =NaN; Rdif =NaN; Ta_yr = NaN; phat=[]; 
%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
INTERFACE_WG;
%%%%% VERB == 1 -- Desktop print optimization-- 
VERB=0; 
%%%% INPUT MANAGEMENT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ans1=questdlg('Do you want to estimate the parameters of the generator or to specify them?','Message','Estimate','Specify ','Specify ');
if strcmp(Ans1,'Specify ')
    Ans2=questdlg('Do you want to load observed data (for comparison with generated series)?','Message','Yes',' No','Yes');
else
    Ans2='Yes';
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp(Ans2,'Yes') 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    prompt={ 'Latititude []','Longitude []', 'Hours of Differences from GMT [h]','Elevation [m a.s.l.]'};
    DEF={'32.13','-110.95','-7','778'};
    g_info=inputdlg(prompt,'Specify Geographic Location:',1,DEF,'on');
    Lat=str2double(char(g_info(1,:)));
    Lon=str2double(char(g_info(2,:)));
    DeltaGMT =str2double(char(g_info(3,:)));
    Zbas=str2double(char(g_info(4,:)));
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    [File_data,Dir_data] = uigetfile('*.mat','LOAD INPUT DATA FILE:');
    cd(Dir_data)
    load(File_data)
    cd(Directory)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
    if nansum(Yr) == 0
        [Yr,Mo,Da,Hr,Mi]=datevec(D);
    else
        D = datenum(Yr,Mo,Da,Hr,Mi,0);  %%% Matlab Data Vector 
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%% DATA CHECK IN 
    if nansum(Yr) == 0  
        errordlg('The Date has not been specified','Error01')
        return
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    dfD=diff(D); dfD(dfD<0.0416)=NaN; dfD(dfD>0.0418)=NaN; 
    if isnan(sum(dfD))
        errordlg('The Date contains gaps','Error05')
        return
    end
    clear dfD 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    LD=length(D);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% DATA CHECK IN
    [Pr,N,Ta,Rsw,U,Ws,Pre,Rdir,Rdif,SPar] = DATA_CHECKIN(D,Pr,N,Ta,Rsw,U,...
        Ws,Pre,Rdir,Rdif,DeltaGMT,Lon,Lat,Zbas,Directory);
    %%% Data Input Yr Mo Da Hr Mi -- Pr N Ta Rsw U Ws Pre  --- Rdir Rdif
    %%% DeltaGMT, Lon,Lat,Zbas
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    D=reshape(D,LD,1);
    Pr=reshape(Pr,LD,1);
    Ta=reshape(Ta,LD,1);
    N=reshape(N,LD,1);
    Rsw=reshape(Rsw,LD,1);
    U=reshape(U,LD,1);
    Ws=reshape(Ws,LD,1);
    Pre=reshape(Pre,LD,1);
    Rdir=reshape(Rdir,LD,1);
    Rdif=reshape(Rdif,LD,1);
    %%%% DATA CONSISTENCY
    prompt={ 'Precipitation [mm/h]','Cloud Cover [0-1]', 'Air Temperature [C]','Solar Radiation [W/m^2]','Relative Humidity [0-1]'...
        'Wind Speed [m/s]','Atmospheric Pressure [mbar]'};
    DEF={num2str(sum(isnan(Pr))/LD),num2str(sum(isnan(N))/LD),num2str(sum(isnan(Ta))/LD),num2str(sum(isnan(Rsw))/LD),num2str(sum(isnan(U))/LD),...
        num2str(sum(isnan(Ws))/LD),num2str(sum(isnan(Pre))/LD)};
    MISSING_VALUE=inputdlg(prompt,'FRACTION OF MISSING VALUES IN INPUT DATA:',1,DEF,'on');
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    esat=611*exp(17.27*Ta./(237.3+Ta)); %% Vapor Pressure Saturation
    ea=U.*esat; %% Vapor Pressure
    a=17.27; b=237.7;
    G= a*Ta./(b+Ta) + log(U);
    Tdew =b*G./(a-G);  %%% Dew Point Temperature
    Tdew(isinf(Tdew))=NaN;
    clear a b G
    %%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Monthly Subdvision  %%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    i=0;
    for i=1:12
        Dm{i}=D(Mo==i);
        Prm{i}= Pr(Mo==i) ;
        Nm{i}= N(Mo==i) ;
        Rswm{i}= Rsw(Mo==i);
        Rdirm{i}=Rdir(Mo==i);
        Rdifm{i}=Rdif(Mo==i);
        Tam{i}=Ta(Mo==i);
        Um{i}=U(Mo==i);
        Tdewm{i}=Tdew(Mo==i);
        eam{i}=ea(Mo==i);
        esatm{i}=esat(Mo==i);
    end
    %%% Prm Nm Dm  Tam Tdewm Rswm Rdirm Rdifm Um eam
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if not(exist('Pr_yr','var'))
        H_TR = 8520; %% Threshold Year Validity %%% 355 Days
        r1=0; r2=0;
        for i=min(Yr):max(Yr)
            if sum(not(isnan(Pr(Yr==i)))) >= H_TR
                r1=r1+1;
                Pr_yr(r1)= nansum(Pr(Yr==i));
            end
            if sum(not(isnan(Ta(Yr==i)))) >= H_TR
                r2=r2+1;
                Ta_yr(r2)= nanmean(Ta(Yr==i));
            end
        end
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Par_yr.E =mean(Pr_yr);
    Par_yr.Cv = std(Pr_yr)/Par_yr.E; 
    Rrr=xcov(Pr_yr,Pr_yr,1,'coeff');
    Par_yr.rho = Rrr(1); %lag-1 autocorrelation 
    Par_yr.skw = skewness(Pr_yr);
    phat=0.025; %% Measurement Error annual precipitation 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
    clear r1 r2 i Rrr 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp(Ans1,'Estimate')
    %%% PARAMETER ESTIMATION  %%%%%%%%%%%%%%%
    tic;
    [Par] = PARAMETER_ESTIMATION(VERB,Dm,Prm,Nm,Tam,Tdewm,Rswm,Rdirm,Rdifm,eam,esatm,Rsw,Ws,Pre,DeltaGMT,Lon,Lat,Zbas,SPar);
    Computational_time_parameter_estimation = toc/60; %% [min]  
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Ans5=questdlg('Do you want to save the parameter?','Message',' SAVE ','CANCEL',' SAVE ');
    if strcmp(Ans5,' SAVE ')
        cd(current_directory)
        [PARAM_WG] = uiputfile('*.mat', 'SAVE AS');
        save(PARAM_WG,'Par','Par_yr'); 
        cd(Directory)
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
else
    [File_parameter,Dir_parameter] = uigetfile('*.mat','LOAD PARAMETER FILE:');
    cd(Dir_parameter)
    load(File_parameter)
    cd(Directory)
    if strcmp(Ans2,' No')
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        prompt={ 'Latititude []','Longitude []', 'Hours of Differences from GMT [h]','Elevation [m a.s.l.]'};
        DEF={'43.76','11.25','1','50.1'};
        g_info=inputdlg(prompt,'Specify Geographic Location:',1,DEF,'on');
        Lat=str2double(char(g_info(1,:)));
        Lon=str2double(char(g_info(2,:)));
        DeltaGMT =str2double(char(g_info(3,:)));
        Zbas=str2double(char(g_info(4,:)));
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%% --control: does the Par_yr structure exists
        if not(exist('Par_yr','var'))
            %%% Specify -->  Pr_yr, Ta_yr
            if not(exist('Pr_yr','var'))
                [File_annual,Dir_annual] = uigetfile('*.mat','LOAD TIME SERIES of ANNUAL PRECIPITATION "Pr_yr":');
                Ta_yr=0;
                cd(Dir_annual)
                load(File_annual)
                cd(Directory)
            end
            %%%%%%%%%%%%%%%%%%%%%%%
            Par_yr.E =mean(Pr_yr);
            Par_yr.Cv = std(Pr_yr)/Par_yr.E;
            Rrr=xcov(Pr_yr,Pr_yr,1,'coeff');
            Par_yr.rho = Rrr(1); %lag-1 autocorrelation
            Par_yr.skw = skewness(Pr_yr);
            phat=0.025; %% Measurement Error annual precipitation
        else
            %%% Specify -->  Pr_yr, Ta_yr
            Pr_yr=NaN;
            Ta_yr=0;
        end
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% SIMULATION
%%% WEATHER GENERATOR %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ans3=questdlg('Do you want to generate the series or visualize previous results?','Message','Generate ','Visualize','Visualize');
%%%%Ans3=questdlg(['The weather generator parameters have been estimated.Do you want to generate the series or visualize previous results?','Message','Generate ','Visualize','Visualize');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp(Ans3,'Generate ')
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    prompt={ 'Start Hour [Yr Mo Da Hr ]','End Hour [Yr Mo Da Hr ]'};
    DEF={'2009 1 1 0','2038 12 31 23'};
    d_info=inputdlg(prompt,'SPECIFY PERIOD OF SIMULATION:',1,DEF,'on');
    Date_s=str2num(char(d_info(1,:)));
    Date_e=str2num(char(d_info(2,:)));
    DS=datenum(Date_s(1),Date_s(2),Date_s(3),Date_s(4),0,0):(1/24):datenum(Date_e(1),Date_e(2),Date_e(3),Date_e(4),0,0);
    [Yrs,Mos,Das,Hrs]=datevec(DS);
    NYR= Date_e(1)-Date_s(1)+1;
    if NYR <= 0
        errordlg('Period of simulation Invalid','Error02')
        return
    end
    clear Date_s Date_e
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    IAV=questdlg('Do you want to enable the interannual variabilty feature?','Message','Yes',' No','Yes');
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if not(exist('DT_fut','var'))
        DT_fut=zeros(1,12);
    end
    %%%%%%%%%%%%%%%%
    tic;
    [Psim,Pyr_AR_orig,Ns,Tas,eas,Us,Tdews,SB,...
    SD,SAB1,SAB2,SAD1,SAD2,PARB,PARD,Wss,Pres]...
        = WEATHER_GENERATOR(DS,Par,NYR,Par_yr,phat,Ta_yr,DeltaGMT,Lon,Lat,Zbas,IAV,VERB,DT_fut);
    Rsws = SB+SD;
    Rdifs =  SD;
    Rdirs = SB ;
    Prs = Psim; 
    Computational_time_WG = toc/60; 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%  clear Dm Prm Nm Tam Tdewm Rswm Rdirm Rdifm Um eam esatm
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Ans4=questdlg('Do you want to save the results?','Message',' SAVE ','CANCEL',' SAVE ');
    if strcmp(Ans4,' SAVE ')
        cd(current_directory)
        [RESULTS_WG] = uiputfile('*.mat', 'SAVE AS');
        if strcmp(Ans2,'Yes')
            save(RESULTS_WG,'DS','Prs','Ns','Tas','eas','Us','Tdews','Rdirs',...
                'Rdifs','SAB1','SAB2','SAD1','SAD2','PARB','PARD','Wss','Pres','Rsws',...
                'Yrs','Mos','Das','Hrs','NYR','Psim','Pyr_AR_orig','D','Pr','Pr_yr','Ta','Ta_yr','N','Tdew','U',...
                'ea','Rsw','Rdir','Rdif','Ws','Pre',...
                'Prm', 'Nm','Tam', 'Rdifm', 'Rdirm', 'Rswm','Um', 'Tdewm','eam');
        else
            save(RESULTS_WG,'DS','Prs','Ns','Tas','eas','Us','Tdews','Rdirs',...
                'Rdifs','SAB1','SAB2','SAD1','SAD2','PARB','PARD','Wss','Pres','Rsws',...
                'Yrs','Mos','Das','Hrs','NYR','Psim');
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        cd(Directory)
    end 
else
    Directory_act= Directory; 
    current_directory_act = current_directory;
    %%%%%%
    [File_result,Dir_result] = uigetfile('*.mat','LOAD RESULT FILE');
    cd(Dir_result)
    load(File_result)
    %%%%%%%
    Directory = Directory_act;  
    current_directory = current_directory_act; 
    cd(Directory)
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% GRAPHICS WEATHER GENERATOR %%%%%%%%%%%%%%%%%
if strcmp(Ans2,'Yes')
   [Pr_yr_s,Ta_yr_s]= GRAPHICS_WG_EXT(DS,Par,NYR,Psim,Pyr_AR_orig,Ns,Tas,eas,Us,Tdews,Rsws,...
        Rdirs,Rdifs,Wss,Pres,D,Pr,Pr_yr,Ta,Ta_yr,N,Tdew,U,ea,Rsw,Rdir,Rdif,Ws,Pre,...
        Prm, Nm,Tam, Rdifm, Rdirm, Rswm,Um, Tdewm,eam);
end
cd(current_directory)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%HD2 = helpdlg('The HOURLY WEATHER GENERATOR has completed the RUN ','HOURLY WEATHER GENERATOR') ;
%waitfor(HD2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%
%%%%%
%
%